'''
<2020.09.17>
Classify the model type to Tree(ensemble) based model and linear model.
'''

Tree_type_1 = ['AdaBoost', 'Bagging', 'ExtraTrees', 'GradientBoosing', 'IsolationForest', 'RandomForest',
        'catboost', 'xgboost','HistGradientBoosting', 'DecisionTree',
        'ExtraTree', 'XGBRegressor', 'XGBClassifier', 'XGB_Regressor', 'XGB_Classifier']

Tree_type_2 = ['LightGBM', 'lightgbm']

Linear = ['Linear', 'Logistic', 'Ridge', 'SGD', 'ElasticNet', 'Lars', 'Lasso',
          'OrthogonalMatchingPursuit', 'ARD', 'BayesianRidge', 'Huber', 'RANSAC', 'TheilSen',
          'Poisson', 'Tweedie', 'Gamma', 'PassiveAggresive', 'lars', 'lasso', 'orthogonal_mp',
          'ridge', 'LogisticRegression', 'LinearRegression']

